diff rational.h @ 641:41e4544b228b libavutil

cosmetics: Use 'num' instead of 'nom' as abbreviation for numerator.
author diego
date Sun, 01 Feb 2009 00:20:45 +0000
parents 8c48a1b999a3
children 70bdd5501662
line wrap: on
line diff
--- a/rational.h	Fri Jan 30 18:52:51 2009 +0000
+++ b/rational.h	Sun Feb 01 00:20:45 2009 +0000
@@ -64,14 +64,14 @@
 /**
  * Reduces a fraction.
  * This is useful for framerate calculations.
- * @param dst_nom destination numerator
+ * @param dst_num destination numerator
  * @param dst_den destination denominator
  * @param nom source numerator
  * @param den source denominator
  * @param max the maximum allowed for dst_nom & dst_den
  * @return 1 if exact, 0 otherwise
  */
-int av_reduce(int *dst_nom, int *dst_den, int64_t nom, int64_t den, int64_t max);
+int av_reduce(int *dst_num, int *dst_den, int64_t num, int64_t den, int64_t max);
 
 /**
  * Multiplies two rationals.
@@ -64,14 +64,14 @@
  * @param dst_den destination denominator
- * @param nom source numerator
+ * @param num source numerator
  * @param den source denominator
@@ -64,14 +64,14 @@
  * @param den source denominator
- * @param max the maximum allowed for dst_nom & dst_den
+ * @param max the maximum allowed for dst_num & dst_den
  * @return 1 if exact, 0 otherwise
  */